@@ -1559,14 +1559,22 @@ def read_tree_nexml(nexml):
         f.close()
     return trees
 
-def read_tree_nexus(nexus):
+def read_tree_nexus(nexus, translate=True):
     '''Read a tree from a Nexus string or file
 
     Args:
         ``nexus`` (``str``): Either a Nexus string or the path to a Nexus file (plain-text or gzipped)
 
+        ``translate`` (``bool``): Translate the node labels on the trees (if the Nexus file has a "Translate" section)
+
     Returns:
         ``dict`` of ``Tree``: A dictionary of the trees represented by ``nexus``, where keys are tree names (``str``) and values are ``Tree`` objects
+
+        If the Nexus file had a "Taxlabels" section, the taxon labels will be stored in the output dictionary as a ``list`` associated with key ``"taxlabels"``
+
+        If any trees in the Nexus file had information (e.g. the first ``...`` in the ``tree STATE_0 [...] = [&R] (...);`` line), all information will be stored in the output dictionary: they will be associated with key ``"info"`` in the output dictionary, and they will be stored in a dictionary where keys are tree names (``str``)
+
+        If ``translate`` was ``True``, if a node ``x`` was translated, ``x.label`` will be the translated label, and ``x.id`` will be the original label (the "ID")
     '''
     if not isinstance(nexus, str):
         raise TypeError("nexus must be a str")
@@ -1576,16 +1584,55 @@ def read_tree_nexus(nexus):
         f = open(expanduser(nexus))
     else:
         f = nexus.splitlines()
-    trees = dict()
+    trees = dict(); taxlabels = None; tr = None; reading_taxlabels = False; reading_translate = False
     for line in f:
         if isinstance(line,bytes):
             l = line.decode().strip()
         else:
             l = line.strip()
-        if l.lower().startswith('tree '):
-            i = l.index('='); left = l[:i].strip(); right = l[i+1:].strip()
-            name = ' '.join(left.split(' ')[1:])
-            trees[name] = read_tree_newick(right)
+        if reading_taxlabels:
+            if l == ';':
+                reading_taxlabels = False; trees['taxlabels'] = taxlabels
+            else:
+                taxlabels.append(l)
+        elif reading_translate:
+            if l == ';':
+                reading_translate = False; trees['translate'] = tr
+            else:
+                parts = l.split(' '); tmp = ' '.join(parts[1:])
+                if tmp.endswith(','):
+                    tmp = tmp[:-1]
+                tr[parts[0]] = tmp
+        elif l.lower().startswith('tree '):
+            # find the `=` that separates the name (and possibly optional info `[...]`) from the actual Newick tree
+            i = l.index('=')
+            try:
+                br = l.index(']'); p = l.index('(')
+                if i < br < p:
+                    i = l.index('=', br)
+            except:
+                pass
+
+            # split tree line and parse each side of `=`
+            i = l.rindex('=', 0, l.index('(')) # find last `=` before first `(` (i.e., before Newick string)
+            left = l[:i].strip(); right = l[i+1:].strip()
+            if '[' in left:
+                name = ' '.join(left.split('[')[0].split(' ')[1:]).strip()
+                if 'info' not in trees:
+                    trees['info'] = dict()
+                trees['info'][name] = left.split('[')[1].split(']')[0].strip()
+            else:
+                name = ' '.join(left.split(' ')[1:])
+            curr_tree = read_tree_newick(right)
+            if translate and tr is not None:
+                for node in curr_tree.traverse_preorder():
+                    if node.label in tr:
+                        node.id = node.label; node.label = tr[node.id]
+            trees[name] = curr_tree
+        elif l.lower() == 'taxlabels':
+            taxlabels = list(); reading_taxlabels = True
+        elif l.lower() == 'translate':
+            tr = dict(); reading_translate = True
     if hasattr(f,'close'):
         f.close()
     if len(trees) == 0:
